pub fn linspace(start: f64, stop: f64, count: usize) -> Vec<f64>Expand description
Returns evenly spaced numbers over a specified closed interval
Analogous to numpy.linspace.
Both start and stop are included in the output (closed interval).
Examples
use plotpy::linspace;
assert_eq!(linspace(0.0, 1.0, 3), vec![0.0, 0.5, 1.0]);
assert_eq!(linspace(0.0, 1.0, 5), vec![0.0, 0.25, 0.5, 0.75, 1.0]);Edge cases
count == 0returns an empty vectorcount == 1returns[start]count == 2returns[start, stop]